@@ -7,7 +7,7 @@
 """Module for DebugMailbox PyOCD Debug probes support."""
 
 import logging
-from typing import List, Any
+from typing import List, Dict, Any
 
 import pyocd
 import pylink
@@ -40,12 +40,12 @@ logging.getLogger('pyocd.probe.common').setLevel(logging.CRITICAL)
 class DebugProbePyOCD(DebugProbe):
     """Class to define PyOCD package interface for NXP SPSDK."""
 
-    def __init__(self, hardware_id: str, ip_address: str = None) -> None:
+    def __init__(self, hardware_id: str, user_params: Dict = None) -> None:
         """The PyOCD class initialization.
 
         The PyOCD initialization function for SPSDK library to support various DEBUG PROBES.
         """
-        super().__init__(hardware_id, ip_address)
+        super().__init__(hardware_id, user_params)
 
         self.pyocd_session = None
         self.di = None
@@ -53,12 +53,13 @@ class DebugProbePyOCD(DebugProbe):
         logger.debug(f"The SPSDK PyOCD Interface has been initialized")
 
     @classmethod
-    def get_connected_probes(cls, hardware_id: str = None) -> List[ProbeDescription]:
+    def get_connected_probes(cls, hardware_id: str = None, user_params: Dict = None) -> List[ProbeDescription]:
         """Get all connected probes over PyOCD.
 
         This functions returns the list of all connected probes in system by PyOCD package.
         :param hardware_id: None to list all probes, otherwice the the only probe with matching
             hardware id is listed.
+        :param user_params: The user params dictionary
         :return: probe_description
         """
         from .utils import DebugProbes
